<?php 
session_start();
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

include 'db.php';
date_default_timezone_set("Asia/Singapore");
include 'post_comment.php';
include 'display_comments.php';

$current_user_id = $_SESSION['user_id'];

$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $current_user_id);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo "<script>alert('User not found.');</script>";
    header('Location: home.php');
    exit();
}
?>


<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>KACHOW</title>
    <link rel="stylesheet" href="../css/style.css">
</head>
<body>
    <nav class="navbar">
        <div class="container">
            <div class="logo">
                <a href="home.php"><img src="../assets/garbace.png" height="42" width="117" alt="Logo"></a>
            </div>
            <ul class="nav-links">
                <li><a href="home.php">Home</a></li>
                <li><a href="fileupload.php">Upload</a></li>
                <li><a href="blog.php">Blog</a></li>
                <li><a href="search.php">Search</a></li>
                <li><a href="logout.php">Logout</a></li>
            </ul>
        </div>
    </nav>
        <div class="container">
            <div class="blog-box">
                <h2 class="title">The Importance of Web Application Security</h2>
                <p class="author">Posted by Admin on March 17, 2024</p>
                <div class="content">
                    <p>Web application security is a critical aspect of modern digital presence. With the increasing reliance on web-based solutions for various tasks, ensuring the security of these applications has become paramount.</p>
                    <p>There are several key areas to focus on when it comes to web application security:</p>
                    <ul>
                        <li><strong>Authentication and Authorization:</strong> Implement strong authentication mechanisms such as multi-factor authentication (MFA) and ensure proper authorization checks to prevent unauthorized access.</li>
                        <li><strong>Data Encryption:</strong> Encrypt sensitive data both at rest and in transit using strong encryption algorithms to protect it from unauthorized access.</li>
                        <li><strong>Input Validation:</strong> Validate all user inputs to prevent common vulnerabilities such as SQL injection, XSS (Cross-Site Scripting), and CSRF (Cross-Site Request Forgery).</li>
                        <li><strong>Security Patches and Updates:</strong> Regularly update your web application, server software, and libraries to patch known security vulnerabilities and stay protected against emerging threats.</li>
                        <li><strong>Secure Configuration:</strong> Configure your web server, database, and other components securely, following best practices and guidelines provided by security experts.</li>
                    </ul>
                    <p>By prioritizing web application security and adopting a proactive approach, businesses can safeguard their data, protect their users, and maintain trust in their online services.</p>
                </div>
            </div>
            
            <div class="comment-section">
                <h2>Comments</h2>
                <div class="comment-form">
                    <form action='post_comment.php' method='POST'>
                        <div class='form-group'>
                            <input type='hidden' name='full_name' value='<?= $user['full_name']; ?>' />
                            <input type='hidden' name='date' value='<?= date('Y-m-d H:i:s'); ?>' />
                            <label for='comment_message'>Comment:</label>
                            <textarea name='comment_message' id='comment_message' required></textarea>
                        </div> 
                        <div class='form-group'>
                            <button type='submit' name='submit_comment'>Post Comment</button>
                        </div>
                    </form>
                </div>
                
                <div class='scroll'>
                    <?php display_comments()?>
                </div>
            </div>
        </div>  
        <div class="back-home">
            <form action="home.php" method="GET">
                <button type="submit" class="back-home-button">&laquo; Back</button>
            </form>
        </div>

    </div>

</body>
</html>
